pub fn can_cancel(child: impl IntoUiNode, enabled: impl IntoVar<bool>) -> UiNodeExpand description
P Defines if
on_cancel
and
on_pre_cancel
command handlers are enabled in the widget and descendants.
Sets the CAN_CANCEL_VAR.
pub fn can_cancel(child: impl IntoUiNode, enabled: impl IntoVar<bool>) -> UiNodeP Defines if
on_cancel
and
on_pre_cancel
command handlers are enabled in the widget and descendants.
Sets the CAN_CANCEL_VAR.