pub fn can_finish(child: impl IntoUiNode, enabled: impl IntoVar<bool>) -> UiNodeExpand description
P Defines if
on_finish
and
on_pre_finish
command handlers are enabled in the widget and descendants.
Sets the CAN_FINISH_VAR.
pub fn can_finish(child: impl IntoUiNode, enabled: impl IntoVar<bool>) -> UiNodeP Defines if
on_finish
and
on_pre_finish
command handlers are enabled in the widget and descendants.
Sets the CAN_FINISH_VAR.