pub fn on_cancel(
child: impl IntoUiNode,
handler: Handler<CommandArgs>,
) -> UiNodeExpand description
P Wizard cancel requested.
Command
This property will subscribe to the
CANCEL_CMD
command scoped on the widget. If set on the Window! root widget it will also subscribe to
the command scoped on the window.
The command handle is enabled by default and can be disabled using the contextual property
can_cancel
.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.