on_pre_begin

Function on_pre_begin 

pub fn on_pre_begin(
    child: impl IntoUiNode,
    handler: Handler<CommandArgs>,
) -> UiNode
P Wizard begin requested.

Command

This property will subscribe to the BEGIN_CMD command scoped on the widget. If set on the Window! root widget it will also subscribe to the command scoped on the window.

The command handle is enabled by default and can be disabled using the contextual property can_begin .

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.