Function pages
Source pub fn pages(wgt: &mut WidgetBuilding, pages: impl IntoVar<Vec<Page>>)
B Defines the wizard pages.
Pages are built on demand, the Page value defines wgt_fn! builders
that are used by wizard when the page needs to be instantiated.
Mixin Property
This property is a mixin, it modifies the widget builder during build, it does not produce a standalone UI node.