#[non_exhaustive]pub struct FooterFnArgs {
pub footer: UiNode,
pub footer_extra: UiNode,
pub index: usize,
pub pages_len: usize,
}Expand description
Arguments for a wizard footer container builder.
See FOOTER_FN_VAR for more details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.Page footer instance.
This can be UiNode::is_list, in this case a layout panel must be generated for
the items, usually an horizontal stack aligned to the Align::END side.
Extra footer content that is the same for all pages.
This is the footer_extra_fn instance.
This can be UiNode::nil if no extra content is defined, otherwise it is
like footer a list or a single node, usually presented as an horizontal stack
aligned to the Align::START side.
index: usizePage index on the pages list.
pages_len: usizeCount of pages on the list.
Implementations